@@ -6,13 +6,16 @@
 #' Extract coefficients from a sequence of regression models
 #' 
 #' Extract coefficients from a sequence of regression models, such as submodels 
-#' along a robust least angle regression sequence, or sparse least trimmed 
-#' squares regression models for a grid of values for the penalty parameter.
+#' along a robust or groupwise least angle regression sequence, or sparse least 
+#' trimmed squares regression models for a grid of values for the penalty 
+#' parameter.
 #' 
 #' @method coef seqModel
-#' @aliases coef.rlars
+#' @aliases coef.rlars coef.grplars coef.tslarsP
 #' 
 #' @param object  the model fit from which to extract coefficients.
+#' @param p  an integer giving the lag length for which to extract coefficients 
+#' (the default is to use the optimal lag length).
 #' @param s  for the \code{"seqModel"} method, an integer vector giving 
 #' the steps of the submodels for which to extract coefficients (the default 
 #' is to use the optimal submodel).  For the \code{"sparseLTS"} method, an 
@@ -31,7 +34,9 @@
 #' (\code{TRUE}, the default) or to omit them (\code{FALSE}).
 #' @param drop  a logical indicating whether to reduce the dimension to a 
 #' vector in case of only one submodel.
-#' @param \dots  additional arguments are currently ignored.
+#' @param \dots  for the \code{"tslars"} method, additional arguments to be 
+#' passed down to the \code{"seqModel"} method.  For the other methods, 
+#' additional arguments are currently ignored.
 #' 
 #' @return  
 #' A numeric vector or matrix containing the requested regression coefficients.
@@ -39,6 +44,8 @@
 #' @author Andreas Alfons
 #' 
 #' @seealso \code{\link[stats]{coef}}, \code{\link{rlars}}, 
+#' \code{\link{grplars}}, \code{\link{rgrplars}}, \code{\link{tslarsP}}, 
+#' \code{\link{rtslarsP}}, \code{\link{tslars}}, \code{\link{rtslars}}, 
 #' \code{\link{sparseLTS}}
 #' 
 #' @example inst/doc/examples/example-coef.R
@@ -64,6 +71,29 @@ coef.seqModel <- function(object, s = NA, zeros = TRUE,
 }
 
 
+#' @rdname coef.seqModel
+#' @method coef tslars
+#' @export
+
+coef.tslars <- function(object, p, ...) {
+  ## initializations
+  # check lag length
+  if(missing(p) || !is.numeric(p) || length(p) == 0) {
+    p <- object$pOpt
+  } else p <- p[1]
+  pMax <- object$pMax
+  if(p < 1) {
+    p <- 1
+    warning("lag length too small, using lag length 1")
+  } else if(p > pMax) {
+    p <- pMax
+    warning(sprintf("lag length too large, using maximum lag length %d", p))
+  }
+  ## extract coefficients for specified lag length
+  coef(object$pFit[[p]], ...)
+}
+
+
 #' @rdname coef.seqModel
 #' @method coef sparseLTS
 #' @export
