@@ -61,11 +61,11 @@ uvec fastRlars(const mat& x, const vec& y, const uword& sMax, const double& c,
 	// start iterative computations
 	for(uword k = 1; k < sMax; k++) {
 		// compute correlations of inactive predictors with new active predictor
-		vec xx = x.unsafe_col(active(k-1));
+		vec xk = x.unsafe_col(active(k-1));
 		#pragma omp parallel for num_threads(ncores) schedule(dynamic)
 		for(uword j = 0; j < m; j++) {
 			vec xj = x.unsafe_col(inactive(j));
-			R(inactive(j), k-1) = corHuberBi(xj, xx, c, prob, tol);
+			R(inactive(j), k-1) = corHuberBi(xj, xk, c, prob, tol);
 		}
 		for(uword j = 1; j < k; j++) {
 			R(active(j-1), k-1) = R(active(k-1), j-1);
@@ -91,7 +91,7 @@ uvec fastRlars(const mat& x, const vec& y, const uword& sMax, const double& c,
         	}
             // compute quantities necessary for computing the step size
         	mat invG = solve(G, eye<mat>(k, k));
-            a = pow(as_scalar(ones<rowvec>(k) * invG * ones<vec>(k)), -0.5);
+            a = 1 / sqrt(as_scalar(ones<rowvec>(k) * invG * ones<vec>(k)));
             w = a * (invG * ones<vec>(k));
         }
         // compute correlations of inactive predictors with equiangular vector
@@ -122,7 +122,7 @@ uvec fastRlars(const mat& x, const vec& y, const uword& sMax, const double& c,
         	signs(k) = -1;
         }
         // update correlations
-		r.insert_rows(k, 1, false);	// do not initialize new memory
+		r.insert_rows(k, 1, false);			// do not initialize new memory
         r(k) = r(k-1) - gamma * a;
 		corY.shed_row(whichMin);
 		corU.shed_row(whichMin);
